@@ -10,9 +10,10 @@ import pandas as pd
 import json
 import tabulate
 from IPython.display import display, HTML
+import time
 
 DEBUG_LEVEL = 2
-
+PLOT_MARGIN_DEFAULT = 50
 
 def generic_callback(response_bytes, payload, log_level, figsize):
     """
@@ -167,6 +168,10 @@ def _process_specific_task(task_response, payload, log_level, figsize):
         return _get_annotations_callback(task_response, payload)
     elif task_type == "ExplainableAI": 
         return _explainable_ai_callback(task_response, payload)
+    elif task_type == "GetWorkflow":
+        return _get_workflow_callback(task_response, payload)
+    elif task_type == "GetLegend":
+        return _get_legend_callback(task_response, payload)
 
     notes_message = ""
     if "Note" in task_response:
@@ -576,6 +581,19 @@ def _plot_mapping_export_callback(task_response, payload, log_level):
 
     return plot
 
+def _crop_plot(img):
+    margin_top = int(img.height * (PLOT_MARGIN_DEFAULT / 2048))
+    margin_side = int(img.width * (PLOT_MARGIN_DEFAULT / 2048))
+    img_array = np.array(img)
+    pixel_first = img_array[0,0]
+    pix_match = np.all(img_array == pixel_first, axis=2)
+    rows, cols = np.where(pix_match == False)
+    min_row = max(np.min(rows) - margin_top, 0)
+    max_row = min(np.max(rows) + margin_top, img_array.shape[0] - 1)
+    min_col = max(np.min(cols) - margin_side, 0)
+    max_col = min(np.max(cols) + margin_side, img_array.shape[1] - 1)
+    crop = img_array[min_row : max_row,  min_col : max_col]
+    return Image.fromarray(crop)
 
 def _export_callback(task_response, payload, figsize):
     """
@@ -595,11 +613,12 @@ def _export_callback(task_response, payload, figsize):
             image_bytes = utils.decompress(utils.get_bytes(payload, start, size))
             image = Image.open(BytesIO(image_bytes))
             image = image.convert("RGB")
+            if "Autocrop" in task_response and task_response["Autocrop"]:
+                image = _crop_plot(image)
             matplotlib.rcParams["figure.figsize"] = figsize
             matplotlib.rcParams["figure.dpi"] = 250
             plt.imshow(np.asarray(image))
             plt.axis("off")
-
             if "Path" in task_response.keys():
                 image.save(task_response["Path"], quality=100)
 
@@ -1054,3 +1073,15 @@ def _extract_annotation_info(key, aInfo):
         return aInfo[key]
     
     return None
+
+def _get_workflow_callback(task_response, payload):
+    if "Workflow" in task_response:
+        return json.loads(task_response["Workflow"]);
+
+    return None
+
+def _get_legend_callback(task_response, payload):
+    if "Legend" in task_response:
+        return json.loads(task_response["Legend"])
+
+    return None
