@@ -335,6 +335,12 @@ def get_features(features):
     :param features: enumerable of pd.Series and strings
     :return: list of feature names
     """
+
+    # [EXPD-20]
+    if isinstance(features, str):
+        raise exceptions.InvalidUsageException(f"`{features}` is not a valid list of column names. "
+                                                   "See documentation for how to pass input features.")
+
     try:
         return list(set([get_name(feat) for feat in features]))
     except Exception:
