@@ -5,7 +5,7 @@ from enum import Enum, unique, auto
 
 class VipAnnotation:
     """
-    The VipAnnotation class contains the basic data and metadata for creating and managing an Annotation in VIP.
+    The VipAnnotation class contains the basic data and metadata for creating and managing an Annotation in Virtualitics Explore.
     """
 
     def __init__(self, a_type=None, 
@@ -29,7 +29,7 @@ class VipAnnotation:
         """
         Constructor for a VipAnnotation instance. See parameter details.
 
-        :param id: :class:`str` specifies a unique identifier provided by VIP.
+        :param id: :class:`str` specifies a unique identifier provided by Virtualitics Explore.
         :param a_type: :class:`AnnotationType` specifies the type of annotation.
         :param name: :class:`str` The name of the annotation (will be displayed in the header bar of the Annotation UI.)
         :param comment: :class:`str` The main body text of the annotation. 
@@ -152,7 +152,7 @@ class VipAnnotation:
             self._id = val
         else:
             utils.raise_invalid_argument_exception(str(type(val)), "id",
-                                                    "must be a 'str' specifying the id of the annotation (generated by VIP).")
+                                                    "must be a 'str' specifying the id of the annotation (generated by Virtualitics Explore).")
 
     @id.deleter
     def id(self):
@@ -661,7 +661,7 @@ class VipAnnotation:
 @unique
 class AnnotationType(Enum):
     """
-    Different types of annotations available in VIP.
+    Different types of annotations available in Virtualitics Explore.
 
     [DATASET, MAPPING, POINT, OBJECT]
     """
