@@ -11,8 +11,8 @@ class VipDashboard:
         """
         Constructor for a VipDashboard instance. See parameter details.
 
-        :param name: :class:'str' specifies a name provided by the user.
-        :param guid: :class:'str' specifies a unique identifier provided by Virtualitics Explore.
+        :param name: :class:`str` specifies a name provided by the user.
+        :param guid: :class:`str` specifies a unique identifier provided by Virtualitics Explore.
         """
         self.name = name
         self.guid = guid
@@ -64,8 +64,8 @@ class VipDashboardTile:
         """
         Constructor for a VipDashboardTile instance. See parameter details.
         
-        :param name: :class:'str' specifies a name provided by the user.
-        :param guid: :class:'str' specifies a unique identifier provided by Virtualitics Explore.
+        :param name: :class:`str` specifies a name provided by the user.
+        :param guid: :class:`str` specifies a unique identifier provided by Virtualitics Explore.
         :param dashboard: :class:`VipDashboard` specifies the VipDashboard instance that owns the tile.
         :param tile_type: :class:`str` specifies the tile type (i.e., Text, Histogram, Pichart, History, etc.)
         """
